==> codacy-plugins_2.12-8.8.2_play_2.7.jar: tool-cache/codacy-sonar-csharp/docs/description/S4823.md <==

Using command line arguments is security-sensitive. It has led in the past to the following vulnerabilities:

- [CVE-2018-7281](http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-7281)
- [CVE-2018-12326](http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-12326)
- [CVE-2011-3198](http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2011-3198)


Command line arguments can be dangerous just like any other user input. They should never be used without being first validated and sanitized.

Remember also that any user can retrieve the list of processes running on a system, which makes the arguments provided to them visible. Thus<br>passing sensitive information via command line arguments should be considered as insecure.

This rule raises an issue when on every program entry points (`main` methods) when command line arguments are used. The goal is to guide<br>security code reviews.

## Ask Yourself Whether

- any of the command line arguments are used without being sanitized first.
- your application accepts sensitive information via command line arguments.


If you answered yes to any of these questions you are at risk.

## Recommended Secure Coding Practices

[Sanitize](https://www.owasp.org/index.php/Input_Validation_Cheat_Sheet) all command line arguments before using them.

Any user or application can list running processes and see the command line arguments they were started with. There are safer ways of providing<br>sensitive information to an application than exposing them in the command line. It is common to write them on the process' standard input, or give the<br>path to a file containing the information.

## Sensitive Code Example


    namespace MyNamespace
    {
        class Program
        {
            static void Main(string[] args) // Sensitive if there is a reference to "args" in the method.
            {
                string myarg = args[0];
                // ...
            }
        }
    }


## See

- [OWASP Top 10 2017 Category A1](https://www.owasp.org/index.php/Top_10-2017_A1-Injection) - Injection
- [MITRE, CWE-88](https://cwe.mitre.org/data/definitions/88.html) - Argument Injection or Modification
- [MITRE, CWE-214](https://cwe.mitre.org/data/definitions/214.html) - Information Exposure Through Process Environment
- [SANS Top 25](https://www.sans.org/top25-software-errors/#cat1) - Insecure Interaction Between Components

==> codacy-plugins_2.12-11.0.1_play_2.6.jar: tool-cache/codacy-sonar-csharp/docs/description/S4823.md <==

Using command line arguments is security-sensitive. It has led in the past to the following vulnerabilities:

- [CVE-2018-7281](http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-7281)
- [CVE-2018-12326](http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2018-12326)
- [CVE-2011-3198](http://cve.mitre.org/cgi-bin/cvename.cgi?name=CVE-2011-3198)


Command line arguments can be dangerous just like any other user input. They should never be used without being first validated and sanitized.

Remember also that any user can retrieve the list of processes running on a system, which makes the arguments provided to them visible. Thus passing sensitive information via command line arguments should be considered as insecure.

This rule raises an issue when on every program entry points (`main` methods) when command line arguments are used. The goal is to guide security code reviews.

## Ask Yourself Whether

- any of the command line arguments are used without being sanitized first.
- your application accepts sensitive information via command line arguments.


If you answered yes to any of these questions you are at risk.

## Recommended Secure Coding Practices

[Sanitize](https://www.owasp.org/index.php/Input_Validation_Cheat_Sheet) all command line arguments before using them.

Any user or application can list running processes and see the command line arguments they were started with. There are safer ways of providing sensitive information to an application than exposing them in the command line. It is common to write them on the process' standard input, or give the path to a file containing the information.

## Sensitive Code Example


    namespace MyNamespace
    {
        class Program
        {
            static void Main(string[] args) // Sensitive if there is a reference to "args" in the method.
            {
                string myarg = args[0];
                // ...
            }
        }
    }


## See

- [OWASP Top 10 2017 Category A1](https://www.owasp.org/index.php/Top_10-2017_A1-Injection) - Injection
- [MITRE, CWE-88](https://cwe.mitre.org/data/definitions/88.html) - Argument Injection or Modification
- [MITRE, CWE-214](https://cwe.mitre.org/data/definitions/214.html) - Information Exposure Through Process Environment
- [SANS Top 25](https://www.sans.org/top25-software-errors/#cat1) - Insecure Interaction Between Components
